#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 http-streams
version:              0.8.7.2
visibility:           public
id:                   http-streams-0.8.7.2-HoROdnhR5PSJb32fgRRDwM
key:                  http-streams-0.8.7.2-HoROdnhR5PSJb32fgRRDwM
license:              BSD-3-Clause
copyright:            © 2012-2020 Athae Eredh Siniath and Others
maintainer:           Andrew Cowie <istathar@gmail.com>
author:               Andrew Cowie <istathar@gmail.com>
stability:            experimental
homepage:             https://github.com/afcowie/http-streams/
synopsis:             An HTTP client using io-streams
description:
    /Overview/

    An HTTP client, using the Snap Framework'\''s '\''io-streams'\'' library to
    hande the streaming IO. The API is optimized for ease of use for the
    rather common case of code needing to query web services and deal with
    the result.

    The library is exported in a single module; see "Network.Http.Client"
    for full documentation.

category:             Web, IO-Streams
abi:                  59409e4c29b4a585a1b6ed4a3a90ce9f
exposed:              True
exposed-modules:
    Network.Http.Client Network.Http.Connection
    Network.Http.Inconvenience Network.Http.ResponseParser

hidden-modules:       Network.Http.Utilities
import-dirs:          /usr/lib/ghc-8.10.5/site-local/http-streams-0.8.7.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/http-streams-0.8.7.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/http-streams-0.8.7.2
hs-libraries:         HShttp-streams-0.8.7.2-HoROdnhR5PSJb32fgRRDwM
depends:
    HsOpenSSL-0.11.7-9H3n3IMqgUEAoxgHxWF4P9
    aeson-1.5.6.0-IA546NaLWlLGqcowhw6tTs
    attoparsec-0.14.1-IwUGXYiDhQIB5nUHrI5Wg8 base-4.14.2.0
    base64-bytestring-1.2.0.1-Gn2QlQL7quxDmGBEoLUsKs
    blaze-builder-0.4.2.1-CvyaA91rGJh3LGq34EOJVB bytestring-0.10.12.0
    case-insensitive-1.2.1.0-6tEs2ust6UoJNkdDoolIXx directory-1.3.6.0
    http-common-0.8.2.1-CF1ywhYu6jA68uB320E80W
    io-streams-1.5.2.1-on5nq7OVSrHHs81Uq5NSL mtl-2.2.2
    network-3.1.2.2-DhUKX0ZpAd35HJ7CPbrOZd
    network-uri-2.6.4.1-FvgDgWAahTMJnOZjiFXR50
    openssl-streams-1.2.3.0-LwBeBEIq8UlFgAd4knFOq0 text-1.2.4.1
    transformers-0.5.6.2
    unordered-containers-0.2.14.0-D9MLkVL2jXfKIhE8RrmI8O

haddock-interfaces:
    /usr/share/doc/haskell-http-streams/html/http-streams.haddock

haddock-html:         /usr/share/doc/haskell-http-streams/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

